@@ -1,7 +1,7 @@
 import gtk
 import gtk.gdk
-import gnomevfs
 import logging
+import deskbar
 import deskbar.interfaces.Controller
 import deskbar.core.Utils
 from deskbar.ui.About import show_about
@@ -18,6 +18,7 @@ class CuemiacWindowController(deskbar.interfaces.Controller):
     def __init__(self, model):
         super(CuemiacWindowController, self).__init__(model)
         self._model.connect("keybinding-activated", self.on_keybinding_activated)
+        self._model.connect("initialized", self.on_core_initialized)
         self._clipboard = gtk.clipboard_get (selection="PRIMARY")
         
     def on_keybinding_activated(self, core, time, paste=True):
@@ -37,10 +38,14 @@ class CuemiacWindowController(deskbar.interfaces.Controller):
         if self._model.get_clear_entry():
             self._view.clear_all()
         window = self._view.get_toplevel()
-        x, y = window.get_position()      
-        self._model.set_window_x(x)      
-        self._model.set_window_y(y)
+        
+        if self._model.get_ui_name() == deskbar.WINDOW_UI_NAME:
+            x, y = window.get_position()
+            self._model.set_window_x(x)
+            self._model.set_window_y(y)
+        
         window.hide()
+        
         return True
 
     def on_show_about(self, sender):
@@ -51,7 +56,7 @@ class CuemiacWindowController(deskbar.interfaces.Controller):
         prefs.show_run_hide(self._view.get_toplevel())
         
     def on_show_help(self, sender):
-        gnomevfs.url_show("ghelp:deskbar")
+        deskbar.core.Utils.launch_default_for_uri_and_scheme("ghelp:deskbar")
         
     def on_query_entry_changed(self, entry):
         self._view.set_clear()
@@ -134,6 +139,11 @@ class CuemiacWindowController(deskbar.interfaces.Controller):
         if not action.is_valid():
             LOGGER.warning("Action is not valid anymore")
             return
+        
+        # Check if only the "Choose action" item is in history
+        if len(self._model.get_history()) == 1:
+            self._view.mark_history_empty(False)
+            
         self._model.get_history().add(text, action)
         action.activate(text)
         if self._model.get_clear_entry():
@@ -146,6 +156,7 @@ class CuemiacWindowController(deskbar.interfaces.Controller):
         history.clear()
         history.reset()
         history.save()
+        self._view.mark_history_empty(True)
         
     def on_history_match_selected(self, history, text, action):
         action.activate(text)
@@ -168,3 +179,6 @@ class CuemiacWindowController(deskbar.interfaces.Controller):
     def on_category_added (self, widget, cat, path):
         if cat.get_id() not in self._model.get_collapsed_cat():
             self._view.cview.expand_row (path, False)
+            
+    def on_core_initialized (self, core):
+        self._view.mark_history_empty ( (len(core.get_history()) == 1) )
